Module errors

Module errors 

This module contains error handling types.

Enums

ForgeError

Functions

ignore_error_handler
This function is a default error handler, simply ignoring all errors
log_error_handler
This function is a default error handler, simply logs all errors
panic_error_handler
This function is a default error handler, simply panic if receiving a message

Type Aliases

ErrorReceiver
ForgeResult