task_forge

Module task

Contains the trait definitions for tasks.

Structs

  • This struct is given to each task at the begining of it

Traits

  • To use a task forge you should implement this trait to your tasks.