This module contains error handling types.
Enums
Functions
- ignore_
error_ handler - This function is a default error handler, simply ignoring all errors
- log_
error_ handler - This function is a default error handler, simply logs all errors
- panic_
error_ handler - This function is a default error handler, simply panic if receiving a message