task_
forge
0.1.1
Module task
Module Items
Structs
Traits
In crate task_
forge
task_forge
Module
task
Contains the trait definitions for tasks.
Structs

Task
Interface
This struct is given to each task at the begining of it
Traits

Task
Trait
To use a task forge you should implement this trait to your tasks.